@@ -54,7 +54,7 @@ def index():
 @app.route('/interactive', methods=['POST', 'GET'])
 def interactive():
     """Interactive classifier."""
-    if request.method == 'GET':
+    if request.method == 'GET' and request.args.get('heartbeat', '') != "":
         return request.args.get('heartbeat', '')
     if request.method == 'POST':
         raw_data_json = request.form['drawnJSON']
